==> xlniuxdata_newGift-1.0.1-20160519.124336-3-sources.jar: com/xunlei/niux/data/newGift/vo/Resources.java <==
package com.xunlei.niux.data.newGift.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by zy on 2016/3/23.
 */
@Table(tableName="resources",pkFieldName="seqId",pkFieldAssign=false)
public class Resources {

    private Long seqId;
    private String resourceName;
    private String resourceType;
    private String simpleDesc;
    private Integer isGameResource;
    private Integer resourcePrice;
    private String gameId;
    private String resourceUnit;
    private Long batchId;
    private String useRule;
    private Integer status;
    private String editBy;
    private String editTime;

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getResourceUnit() {
        return resourceUnit;
    }

    public void setResourceUnit(String resourceUnit) {
        this.resourceUnit = resourceUnit;
    }

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public String getResourceType() {
        return resourceType;
    }

    public void setResourceType(String resourceType) {
        this.resourceType = resourceType;
    }

    public String getSimpleDesc() {
        return simpleDesc;
    }

    public void setSimpleDesc(String simpleDesc) {
        this.simpleDesc = simpleDesc;
    }

    public Integer getIsGameResource() {
        return isGameResource;
    }

    public void setIsGameResource(Integer isGameResource) {
        this.isGameResource = isGameResource;
    }

    public Integer getResourcePrice() {
        return resourcePrice;
    }

    public void setResourcePrice(Integer resourcePrice) {
        this.resourcePrice = resourcePrice;
    }

    public Long getBatchId() {
        return batchId;
    }

    public void setBatchId(Long batchId) {
        this.batchId = batchId;
    }

    public String getUseRule() {
        return useRule;
    }

    public void setUseRule(String useRule) {
        this.useRule = useRule;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }
}

==> xlniuxdata_newGift-1.0.2-20160617.021605-12-sources.jar: com/xunlei/niux/data/newGift/vo/Resources.java <==
package com.xunlei.niux.data.newGift.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by zy on 2016/3/23.
 */
@Table(tableName="resources",pkFieldName="seqId",pkFieldAssign=false)
public class Resources {

    private Long seqId;
    private String resourceName;
    private String resourceType;
    private String simpleDesc;
    private Integer isGameResource;
    private Double resourcePrice;
    private String gameId;
    private String resourceUnit;
    private Long batchId;
    private String useRule;
    private Integer status;
    private String editBy;
    private String editTime;

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getResourceUnit() {
        return resourceUnit;
    }

    public void setResourceUnit(String resourceUnit) {
        this.resourceUnit = resourceUnit;
    }

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public String getResourceType() {
        return resourceType;
    }

    public void setResourceType(String resourceType) {
        this.resourceType = resourceType;
    }

    public String getSimpleDesc() {
        return simpleDesc;
    }

    public void setSimpleDesc(String simpleDesc) {
        this.simpleDesc = simpleDesc;
    }

    public Integer getIsGameResource() {
        return isGameResource;
    }

    public void setIsGameResource(Integer isGameResource) {
        this.isGameResource = isGameResource;
    }

    public Double getResourcePrice() {
        return resourcePrice;
    }

    public void setResourcePrice(Double resourcePrice) {
        this.resourcePrice = resourcePrice;
    }

    public Long getBatchId() {
        return batchId;
    }

    public void setBatchId(Long batchId) {
        this.batchId = batchId;
    }

    public String getUseRule() {
        return useRule;
    }

    public void setUseRule(String useRule) {
        this.useRule = useRule;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }
}
